==> haskell-cryptohash-md5-0.11.100.1-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cryptohash-md5.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptohash-md5
version: 0.11.100.1
id: cryptohash-md5-0.11.100.1-GT4rz3tsXLEGwzbmkU7JrL
key: cryptohash-md5-0.11.100.1-GT4rz3tsXLEGwzbmkU7JrL
license: BSD3
copyright: Vincent Hanquez, Herbert Valerio Riedel
maintainer: Herbert Valerio Riedel <hvr@gnu.org>
homepage: https://github.com/hvr/cryptohash-md5
synopsis: Fast, pure and practical MD5 implementation
description:
    A practical incremental and one-pass, pure API to the
    <https://en.wikipedia.org/wiki/MD5 MD5 hash algorithm>
    (including <https://en.wikipedia.org/wiki/HMAC HMAC> support)
    with performance close to the fastest implementations available in other languages.
    .
    The implementation is made in C with a haskell FFI wrapper that hides the C implementation.
    .
    NOTE: This package has been forked off @cryptohash-0.11.7@ because the @cryptohash@ package
    has been deprecated and so this package continues to satisfy the need for a lightweight package
    providing the MD5 hash algorithm without any dependencies on packages other than
    @base@ and @bytestring@.
    .
    Consequently, this package can be used as a drop-in replacement for @cryptohash@'\''s
    "Crypto.Hash.MD5" module, though with a clearly smaller footprint.
category: Data, Cryptography
exposed: True
indefinite: False
exposed-modules:
    Crypto.Hash.MD5
abi: a731764e1567c4ec9dcf44fdc7c4ba85
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/cryptohash-md5-0.11.100.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/cryptohash-md5-0.11.100.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.1/cryptohash-md5-0.11.100.1
hs-libraries: HScryptohash-md5-0.11.100.1-GT4rz3tsXLEGwzbmkU7JrL
depends:
    base-4.10.0.0 bytestring-0.10.8.2
abi-depends: base-4.10.0.0=835a16347ec1b210054efd02671c29ee
             bytestring-0.10.8.2=590a7a3c0bdcf7a6a59d8c8ef548a44a
haddock-interfaces: /usr/share/doc/haskell-cryptohash-md5/html/cryptohash-md5.haddock
haddock-html: /usr/share/doc/haskell-cryptohash-md5/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cryptohash-md5-0.11.100.1-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cryptohash-md5.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptohash-md5
version: 0.11.100.1
id: cryptohash-md5-0.11.100.1-5TVuvTUpgnc1ichC4pvrWY
key: cryptohash-md5-0.11.100.1-5TVuvTUpgnc1ichC4pvrWY
license: BSD3
copyright: Vincent Hanquez, Herbert Valerio Riedel
maintainer: Herbert Valerio Riedel <hvr@gnu.org>
homepage: https://github.com/hvr/cryptohash-md5
synopsis: Fast, pure and practical MD5 implementation
description:
    A practical incremental and one-pass, pure API to the
    <https://en.wikipedia.org/wiki/MD5 MD5 hash algorithm>
    (including <https://en.wikipedia.org/wiki/HMAC HMAC> support)
    with performance close to the fastest implementations available in other languages.
    .
    The implementation is made in C with a haskell FFI wrapper that hides the C implementation.
    .
    NOTE: This package has been forked off @cryptohash-0.11.7@ because the @cryptohash@ package
    has been deprecated and so this package continues to satisfy the need for a lightweight package
    providing the MD5 hash algorithm without any dependencies on packages other than
    @base@ and @bytestring@.
    .
    Consequently, this package can be used as a drop-in replacement for @cryptohash@'\''s
    "Crypto.Hash.MD5" module, though with a clearly smaller footprint.
category: Data, Cryptography
exposed: True
indefinite: False
exposed-modules:
    Crypto.Hash.MD5
abi: 60e06478e748fb839d45cecac76e5b66
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/cryptohash-md5-0.11.100.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/cryptohash-md5-0.11.100.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/cryptohash-md5-0.11.100.1
hs-libraries: HScryptohash-md5-0.11.100.1-5TVuvTUpgnc1ichC4pvrWY
depends:
    base-4.10.1.0 bytestring-0.10.8.2
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
haddock-interfaces: /usr/share/doc/haskell-cryptohash-md5/html/cryptohash-md5.haddock
haddock-html: /usr/share/doc/haskell-cryptohash-md5/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
